import requests
import json
import pandas as pd
from pandas.io.json import json_normalize

from .discover import Discover
from .helpers import get_dataset_name_from_doc_id
from .helpers import make_discover_request

class FeatureRepo(Discover):
    def __init__(self, endpoint):
        self.endpoint = endpoint

    def get_feature_values(self, feature_name, n=100):
        payload = { 
          "query": {
              "match": {"kw_index": feature_name}
          },
        'size' : n
        }
        url =  self.host + '/' + self.endpoint + '/_search'
        r = make_discover_request('GET', url, json = payload)
        output = r.json()
        
        feature_sample_values = []
        for doc_dict in output["hits"]["hits"]:
            dataset_name = get_dataset_name_from_doc_id(doc_dict["_source"]["kw_doc_id"])
            feature_name = doc_dict["_source"]["kw_index"]
            sample_values = [[feature_name] + list(d.values()) + [dataset_name] for d in doc_dict['_source']['kw_column'] if 'kw_index' not in d.values()]
            feature_sample_values += sample_values
        feature_sample_df = pd.DataFrame(feature_sample_values)
        feature_sample_df.columns = ["feature_name", "sample", "value", "dataset"]
        return feature_sample_df


    def get_feature_values_sc(self, feature_name, n = 100):
        
        payload = { 
          "query": {
              "match": {"kw_index": feature_name}
          },
        'size' : n
        }
        url =  self.host + '/' + self.endpoint + '/_search'
        r = make_discover_request('GET', url, json = payload)
        output = r.json()

        feature_sample_values = []
        for doc_dict in output["hits"]["hits"]:
            dataset_name = doc_dict["_source"]["kw_doc_id"]
            feature_name = doc_dict["_source"]["kw_index"]            
            sample_values = [[feature_name] + [k] + [v] + [dataset_name] for k,v in doc_dict['_source'].items() if "geneexp" in k]
            feature_sample_values += sample_values

        feature_sample_df = pd.DataFrame(feature_sample_values)
        feature_sample_df.columns = ["feature_name", "celltype", "value", "dataset"]
        return feature_sample_df